@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: forms.py 10851 2018-03-18 00:28:06Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
+# $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 9579 $
+# $Revision: 10851 $
 
 from django import forms
 from django.utils.translation import gettext as _
 
-from Theophrastus.editor.TinyMCEWidget import CustomTinyMCEWidget
+from tinymce.widgets import TinyMCE
 from Theophrastus.newsletter_extension.models import Header, Footer
 
+# Temporarily use CustomTinyMCEWidget from editor app to avoid bug in header
+# editor page. 
+# See more at https://code.nuwainfo.com/trac/mercurius/ticket/3057#comment:51
+from Theophrastus.editor.TinyMCEWidget import CustomTinyMCEWidget
+
 class HeaderTinyMCEForm(forms.ModelForm):
     """
     Form for header.
