@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10797 2018-03-01 02:31:02Z David $
+# $Id: admin.py 10838 2018-03-12 10:54:45Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10797 $
-
-from HTMLParser import HTMLParseError
+# $Date: 2018-03-12 18:54:45 +0800 (Mon, 12 Mar 2018) $
+# $Revision: 10838 $
 
 from django.conf import settings
 from django.contrib import admin
@@ -24,10 +22,6 @@ from django.utils.translation import ugettext as _
 from emencia.django.newsletter.models import Newsletter
 
 from Theophrastus.editor.admin import NewsletterTinyMCEAdmin
-from Theophrastus.cloud.Mailer import CloudMailer
-
-ENABLE_FAKE_MAIL = settings.ENABLE_FAKE_MAIL
-ENABLE_FAKE_SMTP = settings.ENABLE_FAKE_SMTP
 
 def attach(data, attachData):
     data = list(data)
@@ -73,30 +67,6 @@ class NewsletterStatisticsAdmin(NewsletterTinyMCEAdmin):
     subscriberLink.allow_tags = True
     subscriberLink.short_description = _('Subscribers')
 
-    def send_mail_test(self, request, queryset):
-        """
-        Send newsletter in test.
-        """
-        for newsletter in queryset:
-            if newsletter.test_contacts.count():
-                try:
-                    mailer = CloudMailer(newsletter, test=True,
-                                         fakeMail=ENABLE_FAKE_MAIL,
-                                         fakeSMTP=ENABLE_FAKE_SMTP)
-                    mailer.run()
-                except HTMLParseError:
-                    self.message_user(
-                        request,
-                        _('Unable send newsletter, due to errors within HTML.'))
-                    continue
-                self.message_user(
-                    request, _('%s successfully sent.') % newsletter)
-            else:
-                self.message_user(
-                    request,
-                    _('No test contacts assigned for %s.') % newsletter)
-    send_mail_test.short_description = _('Send test email')
-
     fieldsets = getFieldset(NewsletterTinyMCEAdmin.fieldsets)
 
     list_display = attach(
